# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

* [`tajine`](#tajine): Deploy and configure Tajine, a registration authority pluged to CFSSL PKI.

## Classes

### <a name="tajine"></a>`tajine`

Deploy and configure Tajine, a registration authority pluged to CFSSL PKI.

#### Examples

##### 

```puppet
class { 'tajine':
  trusted_hosts     => '^example\.org$|^tajine\.example\.org$',
  sys_rootpath      => '/var/www/tajine.example.org',
  sys_rootpath_mode => '0700',
  sys_user          => 'www-data',
  sys_group         => 'www-data',
}
```

#### Parameters

The following parameters are available in the `tajine` class:

* [`download_url`](#download_url)
* [`download_checksum`](#download_checksum)
* [`checksum_type`](#checksum_type)
* [`app_name`](#app_name)
* [`app_shortname`](#app_shortname)
* [`app_secret`](#app_secret)
* [`config_path`](#config_path)
* [`var_path`](#var_path)
* [`trusted_hosts`](#trusted_hosts)
* [`sys_usermanage`](#sys_usermanage)
* [`sys_user`](#sys_user)
* [`sys_group`](#sys_group)
* [`sys_rootpath`](#sys_rootpath)
* [`sys_rootpath_mode`](#sys_rootpath_mode)
* [`cfssl_host`](#cfssl_host)
* [`cfssl_port`](#cfssl_port)
* [`db_manage`](#db_manage)
* [`db_host`](#db_host)
* [`db_version`](#db_version)
* [`db_user`](#db_user)
* [`db_password`](#db_password)
* [`db_name`](#db_name)
* [`smtp_host`](#smtp_host)
* [`smtp_port`](#smtp_port)
* [`smtp_user`](#smtp_user)
* [`smtp_password`](#smtp_password)
* [`smtp_mailfrom`](#smtp_mailfrom)
* [`smtp_mailalertingto`](#smtp_mailalertingto)

##### <a name="download_url"></a>`download_url`

Data type: `Stdlib::HTTPSUrl`

URL where Tajine archive is stored.

Default value: `'https://gitlab.adullact.net/adullact/pki/tajine/-/package_files/261/download'`

##### <a name="download_checksum"></a>`download_checksum`

Data type: `String[1]`

Archive file checksum (match checksum_type) used to verify of archive file.

Default value: `'2b6c9655b3bbc8ad2a9b32445ae54a31e61f4afb5fe96ac1f7f753792fe9056e'`

##### <a name="checksum_type"></a>`checksum_type`

Data type: `Enum['md5', 'sha1', 'sha2', 'sha256', 'sha384', 'sha512']`

Checksum type given with download_checksum.

Default value: `'sha256'`

##### <a name="app_name"></a>`app_name`

Data type: `String[1]`

A custom string displayed to users as name of service.

Default value: `'Tajine - Registration authority (RA)'`

##### <a name="app_shortname"></a>`app_shortname`

Data type: `String[1]`

A custom string displayed to users as short name of service.

Default value: `'Tajine (RA)'`

##### <a name="app_secret"></a>`app_secret`

Data type: `String[1]`

Application secret is required to generate CSRF tokens

Default value: `'ThisTokenIsNotSoSecretChangeIt'`

##### <a name="config_path"></a>`config_path`

Data type: `Stdlib::Absolutepath`

Directory where Tajine configuration file is stored.

Default value: `'/etc/tajine'`

##### <a name="var_path"></a>`var_path`

Data type: `Stdlib::Absolutepath`

Directory where Tajine stores var files.

Default value: `'/var/tajine'`

##### <a name="trusted_hosts"></a>`trusted_hosts`

Data type: `String[1]`

Regular expression listing allowed domains and IP to prevent HTTP Host header attacks

Default value: `$facts['networking']['fqdn']`

##### <a name="sys_usermanage"></a>`sys_usermanage`

Data type: `Boolean`

To enable/disable the creation of system user and group. To permit manage then by external process.

Default value: ``true``

##### <a name="sys_user"></a>`sys_user`

Data type: `String[1]`

Operating system user account owner of Tajine files

Default value: `'tajine'`

##### <a name="sys_group"></a>`sys_group`

Data type: `String[1]`

Operating system group owner of CFSSL files

Default value: `'tajine'`

##### <a name="sys_rootpath"></a>`sys_rootpath`

Data type: `Stdlib::Absolutepath`

Path where Tajine is installed

Default value: `'/opt/tajine'`

##### <a name="sys_rootpath_mode"></a>`sys_rootpath_mode`

Data type: `String`

Unix mode set to path defined by $sys_rootpath

Default value: `'0750'`

##### <a name="cfssl_host"></a>`cfssl_host`

Data type: `Stdlib::HTTPUrl`

CFSSL host to use

Default value: `'http://127.0.0.1'`

##### <a name="cfssl_port"></a>`cfssl_port`

Data type: `Stdlib::Port`

CFSSL port to use

Default value: `8080`

##### <a name="db_manage"></a>`db_manage`

Data type: `Boolean`

To enable/disable installation of local PostgreSQl server, creation of role and database. To permit manage then by external process.

Default value: ``true``

##### <a name="db_host"></a>`db_host`

Data type: `Stdlib::Host`

PostgreSQL server to use

Default value: `'127.0.0.1'`

##### <a name="db_version"></a>`db_version`

Data type: `String[1]`

Version of PostgreSQL server

Default value: `'14'`

##### <a name="db_user"></a>`db_user`

Data type: `String[1]`

Database user used to connect PostgreSQL server

Default value: `'dbtajine'`

##### <a name="db_password"></a>`db_password`

Data type: `Variant[String[1], Sensitive[String]]`

Database password used to connect PostgreSQL server

Default value: `('changeit')`

##### <a name="db_name"></a>`db_name`

Data type: `String[1]`

Database name used by Tajine

Default value: `'tajine'`

##### <a name="smtp_host"></a>`smtp_host`

Data type: `Stdlib::Host`

SMTP host to use

Default value: `'127.0.0.1'`

##### <a name="smtp_port"></a>`smtp_port`

Data type: `Stdlib::Port`

SMTP port to use

Default value: `25`

##### <a name="smtp_user"></a>`smtp_user`

Data type: `Optional[String[1]]`

SMTP user used with SMTP auth. If user is email, use username%40example.org instead of username@example.org.

Default value: ``undef``

##### <a name="smtp_password"></a>`smtp_password`

Data type: `Optional[Variant[String[1], Sensitive[String]]]`

SMTP password used with SMTP auth

Default value: ``undef``

##### <a name="smtp_mailfrom"></a>`smtp_mailfrom`

Data type: `Stdlib::Email`

Who the email sent by Tajine should come from.

Default value: `"admin@${facts['networking']['domain']}"`

##### <a name="smtp_mailalertingto"></a>`smtp_mailalertingto`

Data type: `Stdlib::Email`

Email address for alert notifications (web application not working properly, ...)

Default value: `"monitor@${facts['networking']['domain']}"`

